Hermes::Engine.routes.draw do
  namespace :api do
    namespace :dmo do
      resources :applicants do
        member do
          get 'eligible_offers'

          resources :notifications, targetable_type: 'Hermes::Applicant', controller: 'notification_center/notifications', only: %i[index show destroy], param: :notification_id do
            member do
              get :move
              put :open
            end
            collection do
              post :open_all
            end
          end
          resources :subscriptions, targetable_type: 'Hermes::Applicant', controller: 'notification_center/subscriptions', only: %i[index show], param: :subscription_id do
            member do
              put :subscribe
              put :unsubscribe
            end
          end
        end

        collection do
          get :find_by_nud
        end
      end

      resources :entity_validations
      resources :entities do
        member do
          post 'create_applicant'
          post 'create_user'
          post 'create_supervisor'
          post 'add_points', to: "entities#add_points"
        end
        resources :housing_request_entity_form_levels
      end
      resources :housing_request_entity_forms do
        get :actives, on: :collection
        get :show_request, on: :member
      end
      resources :entity_codes, only: [:index, :create, :destroy]
      resources :lessor_objective_histories
      resources :housing_applications do
        collection do
          post :attribution
        end
      end
      resources :untensed_areas

      post 'housing_applications/update_status', to: "housing_applications#update_status"

      resources :housing_offers do
        collection do
          get 'with_validated_applications/:id', action: 'with_validated_applications_for'
          get 'with_validated_applications'
        end
        member do
          resources :pictures, only: [:create, :update, :destroy]
          get 'eligible_requests'
          get 'selected_applications'
          post 'selected_applications', to: 'housing_offers#post_selected_applications'
          get "all_applications",  to: 'housing_offers#all_applications'
          get 'history'
          get 'detailed_score'
          get 'score_position'
        end
      end

      resources :housing_channels
      resources :housing_channel_settings
      resources :housing_offer_expiration_settings
      resources :public_housing_offers

      resources :housing_requests do
        collection do
          get 'clp_details'

        end
        member do
          get 'entity_note'
          get 'internal_note'
          put 'update_internal_note'
          put 'update_entity_note'

          get 'housing_request_folder'
          get 'entity_requests'
          get 'waiting_points'
          get 'spent_points'
          post 'add_points_to_housing_request'
          post 'housing_request_folder/start_treatment', to: "housing_requests#start_treatment"
          post 'add_housing_channel'
          post 'validate_housing_channel'
          post 'update_from_sne'
          post 'validate_code'
        end
      end

      post 'required_documents/:id/send_files', to: "required_documents#send_files"
      patch 'required_documents/:id', to: "required_documents#update"
      put 'required_documents/:id', to: "required_documents#update"
      delete 'required_documents/:id/files', to: "required_documents#delete_files"
      resources :lessors do
        member do
          get 'all_objectives'
          get 'active_objectives'
          get 'current_operation_names'
          put :add_user
          put :remove_user
        end
      end

      resources :lessor_objectives
      resources :nuds do
        member do
          post 'send_pin_code_on_mail'
          post 'authentify_with_pin_code'
        end
      end
      resources :thresholds
      resources :contact_groups
      resources :statuses do
        get :applications_history, on: :collection
      end

      namespace :public_forms do
        get 'captcha'
        post 'confirm'
      end 

      get '/nuds/sne_department_list', to: "nuds#sne_department_list"
      resources :reservation_holders

      get 'doc', to: "documentation#show_doc"
      get 'changelog', to: "documentation#show_changelog"
    end

    namespace :rex do
      get 'root_elements', to: 'rex#root_elements'
      get ':id', to: 'rex#show', as: :show
    end
  end
  namespace :admin_thresholds do
    get 'index'
    post 'create'
    get 'download_csv'
  end
  get '/hermes/gedfile/*path', to: "geds#file", :format => false
end
